import numpy as np
import matplotlib.pyplot as plt

#compute VADC from VOC=1


freqs=np.arange(10e6,300e6,1e6) #Hz
axis=3
plotflag=0
name=[0,'NS','EW','Z']


def interp(x,y,z):
    return np.interp(x,y,z)

def plotpolar(sMatrix,title=''):
    plt.plot(freqs/1e6,np.abs(sMatrix[:,0,0]))#s11
    plt.plot(freqs/1e6,np.abs(sMatrix[:,0,1]))#s12
    plt.plot(freqs/1e6,np.abs(sMatrix[:,1,0]))#s21
    plt.plot(freqs/1e6,np.abs(sMatrix[:,1,1]))#s22
    plt.title(title)
    plt.legend(['s11','s12','s21','s22'])
    plt.xlabel('Frequency [MHz]')
    plt.ylabel('abs(s-parameters)')
    plt.savefig(title+'Abssparam.png')
    plt.show()  
      
    plt.plot(freqs/1e6,np.angle(sMatrix[:,0,0]))#s11
    plt.plot(freqs/1e6,np.angle(sMatrix[:,0,1]))#s12
    plt.plot(freqs/1e6,np.angle(sMatrix[:,1,0]))#s21
    plt.plot(freqs/1e6,np.angle(sMatrix[:,1,1]))#s22
    plt.title(title)
    plt.legend(['s11','s12','s21','s22'])
    plt.xlabel('Frequency [MHz]')
    plt.ylabel('phase(s-parameters)')
    plt.savefig(title+'Phasesparam.png')
    plt.show()   
    
def plotalgebra(sMatrix,title=''):
    plt.plot(freqs/1e6,np.real(sMatrix[:,0,0]))#s11
    plt.plot(freqs/1e6,np.real(sMatrix[:,0,1]))#s12
    plt.plot(freqs/1e6,np.real(sMatrix[:,1,0]))#s21
    plt.plot(freqs/1e6,np.real(sMatrix[:,1,1]))#s22
    plt.title(title)
    plt.legend(['s11','s12','s21','s22'])
    plt.xlabel('Frequency [MHz]')
    plt.ylabel('real(s-parameters)')
    plt.savefig(title+'Realsparam.png')
    plt.show()  
      
    plt.plot(freqs/1e6,np.imag(sMatrix[:,0,0]))#s11
    plt.plot(freqs/1e6,np.imag(sMatrix[:,0,1]))#s12
    plt.plot(freqs/1e6,np.imag(sMatrix[:,1,0]))#s21
    plt.plot(freqs/1e6,np.imag(sMatrix[:,1,1]))#s22
    plt.title(title)
    plt.legend(['s11','s12','s21','s22'])
    plt.xlabel('Frequency [MHz]')
    plt.ylabel('imag(s-parameters)')
    plt.savefig(title+'Imagsparam.png')
    plt.show()       

    
def fromABCDtoS(ABCDmatrix,Z0):
    #normalize port 1 and port 2 to Z0
    A=ABCDmatrix[:,0,0]
    B=ABCDmatrix[:,0,1]
    C=ABCDmatrix[:,1,0]
    D=ABCDmatrix[:,1,1]
    a=np.zeros((len(freqs),2,2),dtype='complex')    
    div=A+B/Z0+C*Z0+D
    a[:,0,0]=(A+B/Z0- C*Z0 -D) /div
    a[:,0,1]=2*(A*D-C*B)/div
    a[:,1,0]=2/div
    a[:,1,1]=(-A+B/Z0- C*Z0 +D) /div
    return a
    
    
def fromStoABCD(sMatrix,Z01,Z02):
    S11=sMatrix[:,0,0]
    S12=sMatrix[:,0,1]
    S21=sMatrix[:,1,0]
    S22=sMatrix[:,1,1]        
    a=np.zeros((len(freqs),2,2),dtype='complex')
    a[:,0,0]=((1+S11)*(1-S22)+S12*S21) / (2*S21)
    a[:,0,1]=((1+S11)*(1+S22)-S12*S21) / (2*S21)
    a[:,1,0]=((1-S11)*(1-S22)-S12*S21) / (2*S21)
    a[:,1,1]=((1-S11)*(1+S22)+S12*S21) / (2*S21) #beware, typo in a book
    factor=np.array([[1/np.sqrt(Z02/Z01),np.sqrt(Z01*Z02)],[1/np.sqrt(Z01*Z02),1/np.sqrt(Z01/Z02)]]) #to denormalize a
    return a*factor
    
    
def fromPolartoAlgebra(sFile,s2p,dB=1):
    lenS=1
    if s2p:
        lenS=4
    sAlgebra=np.zeros((len(freqs),lenS),dtype='complex')
    print(sFile[0,0],sFile[-1,0])
    for i in range(1,lenS*2+1,2):
        if dB:
            #r=10**(interp(freqs,sFile[:,0],sFile[:,i])/20)
            r=10**(sFile[:,i]/20)
        else:
            #r=interp(freqs,sFile[:,0],sFile[:,i])
            r=sFile[:,i]
        #phi=interp(freqs, sFile[:,0], sFile[:,i+1])
        phi=sFile[:,i+1]*np.pi/180
        #sAlgebra[:,int((i-1)/2)]=r*np.cos(phi*np.pi/180) +1j*r*np.sin(phi*np.pi/180)
        complexnum=r*np.exp(1j*phi)
        sAlgebra[:,int((i-1)/2)]=interp(freqs,sFile[:,0],np.real(complexnum)) +1j*interp(freqs,sFile[:,0],np.imag(complexnum))
        intreshape=int(np.ceil(lenS/2))
    return np.swapaxes(np.reshape(sAlgebra,(len(freqs),intreshape,intreshape)),1,2)

def fromAlgebratoAlgebra(sFile,s2p):
    lenS=1
    if s2p:
        lenS=4
    sAlgebra=np.zeros((len(freqs),lenS),dtype='complex')
    print(sFile[0,0],sFile[-1,0])
    for i in range(1,lenS*2+1,2):
        re=interp(freqs,sFile[:,0],sFile[:,i])
        im=interp(freqs, sFile[:,0], sFile[:,i+1])
        sAlgebra[:,int((i-1)/2)]=re +1j*im
        intreshape=int(np.ceil(lenS/2))
    return np.swapaxes(np.reshape(sAlgebra,(len(freqs),intreshape,intreshape)),1,2)


#Load s-param files content and plot if flag=1
#sRevBalunF=np.loadtxt('Xidian/v2/balun_reverse.s2p',skiprows=6)
sRevBalunF=np.loadtxt('Xidian/v2/balun13in20230612.s2p',skiprows=6)
sMatchingNetF=np.loadtxt('Xidian/v2/XY_matching_network.s2p',skiprows=6)
if axis==3:
    sMatchingNet=np.loadtxt('Xidian/v2/Z_matching_network.s2p',skiprows=6)
sLNAF=np.loadtxt('Xidian/v2/lna.s2p',skiprows=6)
sCableConnectorF=np.loadtxt('Xidian/rfchain/cable+Connector.s2p',skiprows=6)
sVGAFilterF=np.loadtxt('Xidian/rfchain/vga20db+filter.s2p',skiprows=6)
#sBalunLoadF=np.loadtxt('Xidian/rfchain/zload_balun_200ohm.s1p',skiprows=6)
sBalunLoadF=np.loadtxt('Xidian/rfchain/S_balun_AD.s1p',skiprows=6)
sFinalBalunF=np.loadtxt('Xidian/rfchain/balun_before_ad.s2p',skiprows=6)

sRevBalun=fromPolartoAlgebra(sRevBalunF,1,0)
sMatchingNet=fromPolartoAlgebra(sMatchingNetF,1,0)
sLNA=fromPolartoAlgebra(sLNAF,1)
sCableConnector=fromPolartoAlgebra(sCableConnectorF,1)
sVGAFilter=fromPolartoAlgebra(sVGAFilterF,1)
sFinalBalun=fromPolartoAlgebra(sFinalBalunF,1,0)
#sBalunLoad=fromAlgebratoAlgebra(sBalunLoadF,0)
sBalunLoad=fromPolartoAlgebra(sBalunLoadF,0,1)

#ZantF=np.loadtxt('Xidian/v1/ant1.5m/Z_ant_1.5m.csv',skiprows=6,delimiter=',')
ZantF=np.loadtxt('Xidian/v1/ant3.2m/Z_ant_3.2m.csv',skiprows=6,delimiter=',')
ZantX=interp(freqs,ZantF[:,0]*1e6,ZantF[:,1])+1j*interp(freqs,ZantF[:,0]*1e6,ZantF[:,2])
ZantY=interp(freqs,ZantF[:,0]*1e6,ZantF[:,3])+1j*interp(freqs,ZantF[:,0]*1e6,ZantF[:,4])
ZantZ=interp(freqs,ZantF[:,0]*1e6,ZantF[:,5])+1j*interp(freqs,ZantF[:,0]*1e6,ZantF[:,6])

Zant=ZantX
if axis==2:
    Zant=ZantY
if axis==3:
    Zant=ZantZ
    
Zload=50*(1+sBalunLoad[:,0,0])/(1-sBalunLoad[:,0,0]);    

ABCDfinalBalun=fromStoABCD(sFinalBalun,50,50)    
#since Zload(balun+200ohm)=(Abalun*ZADC+Bbalun)/(Cbalun*ZADC+Dbalun)
ZADC=(Zload*ABCDfinalBalun[:,1,1]-ABCDfinalBalun[:,0,1])/(ABCDfinalBalun[:,0,0]-Zload*ABCDfinalBalun[:,1,0])    
    
    
if plotflag: 
    plt.plot(freqs/1e6,np.real(ZADC))
    plt.plot(freqs/1e6,np.imag(ZADC))
    plt.title('Z$_{ADC}$')
    plt.legend(['R$_{ADC}$','X$_{ADC}$'])
    plt.xlabel('Frequency [MHz]')
    plt.ylabel('Impedance [$\Omega$]')
    plt.savefig('ZADC.png')
    plt.show()   
    plt.plot(freqs/1e6,np.real(Zant))
    plt.plot(freqs/1e6,np.imag(Zant))
    plt.title('Z$_{ant}$')
    plt.legend(['R$_{ant}$','X$_{ant}$'])
    plt.xlabel('Frequency [MHz]')
    plt.ylabel('Impedance [$\Omega$]')
    plt.savefig('Zant.png')
    plt.show()
    plt.plot(freqs/1e6,np.real(Zload))
    plt.plot(freqs/1e6,np.imag(Zload))
    plt.title('Z$_{load}$')
    plt.legend(['R$_{ant}$','X$_{ant}$'])
    plt.xlabel('Frequency [MHz]')
    plt.ylabel('Impedance [$\Omega$]')
    plt.savefig('Zload.png')
    plt.show()


    plotalgebra(sRevBalun,'RevBalun')
    plotalgebra(sMatchingNet,'MatchingNet')    
    plotalgebra(sLNA,'LNA')
    plotalgebra(sCableConnector,'sCableConnector')
    plotalgebra(sVGAFilter,'VGAFilter')
    plotalgebra(sFinalBalun,'FinalBalun')


def ComputeTFfromS(sMatrix,ZL,Z01,Z02,title):
    Gant=(Zant-Z01)/(Zant+Z01)
    GL=(ZL-Z02)/(ZL+Z02)
    Gin=sMatrix[:,0,0]+(sMatrix[:,0,1]*sMatrix[:,1,0])/(1-sMatrix[:,1,1]*GL)
    Voc=1
    V2=Voc*0.5*(1-Gant)/(1-Gin*Gant)*sMatrix[:,1,0]*(GL+1)/(1-sMatrix[:,1,1]*GL)
    return V2



ABCDtot=np.matmul(np.matmul(np.matmul(np.matmul(fromStoABCD(sRevBalun,50,50),fromStoABCD(sMatchingNet,50,50)),fromStoABCD(sLNA,50,50)),fromStoABCD(sCableConnector,50,50)),fromStoABCD(sVGAFilter,50,50))
ABCDwbalun=np.matmul(np.matmul(np.matmul(np.matmul(np.matmul(fromStoABCD(sRevBalun,50,50),fromStoABCD(sMatchingNet,50,50)),fromStoABCD(sLNA,50,50)),fromStoABCD(sCableConnector,50,50)),fromStoABCD(sVGAFilter,50,50)),fromStoABCD(sFinalBalun,50,50))


#tests, norm Imp does not matter at the end
sMatrix=fromABCDtoS(ABCDtot,50)
plotpolar(sMatrix,'TotalRFchain')
sMatrix=fromABCDtoS(ABCDtot,1000)
plotpolar(sMatrix,'TotalRFchain')
V2th=ComputeTFfromS(sMatrix,Zload,1000,1000,'Device = Full RF chain')
sMatrixwbalun=fromABCDtoS(ABCDwbalun,50)
V2sp=ComputeTFfromS(sMatrixwbalun,ZADC,50,50,'Device = Full RF chain')
plt.plot(np.abs(V2th)*2)
plt.plot(np.abs(V2sp))
title='Device = Full RF chain - S-param method'
plt.title(title)
plt.xlabel('Frequencies [MHz]')
plt.ylabel('X abs(transfer function) : abs(FFT(V$_L$)/FFT(V$_{oc}))$')
plt.legend(['Theoretical final balun','S param final balun'])
plt.show()


np.savetxt('TF2_20dB_'+name[axis],V2sp)


def ComputeTFfromABCD(ABCD,ABCDbis,ZL):
    Zin=(ABCD[:,0,0]*ZL+ABCD[:,0,1])/(ABCD[:,1,0]*ZL+ABCD[:,1,1])
    #plt.plot(np.real(Zin))
    #plt.plot(np.imag(Zin))
    #plt.title('Zin')
    #plt.show()
    Voc=1 #V2 scales linearly with Voc
    I1=Voc/(Zin+Zant)
    V1=I1*Zin
    V1I1=np.zeros((len(freqs),2,1),dtype='complex')
    V1I1[:,0,0]=V1
    V1I1[:,1,0]=I1


    invABCD=np.linalg.inv(ABCD)
    invABCDbis=np.linalg.inv(ABCDbis)
    V2=np.matmul(invABCD,V1I1)[:,0,0]
    I2=np.matmul(invABCD,V1I1)[:,1,0]
    V2balun=np.matmul(invABCDbis,V1I1)[:,0,0]
    I2balun=np.matmul(invABCDbis,V1I1)[:,1,0]

    return V2,V2balun,I2
    
    
def ComputeVoltageAtDevice(V2,I2,ABCDdevice): #I2 is relative to the load here (no minus)
    V2I2=np.zeros((len(freqs),2,1),dtype='complex')
    V2I2[:,0,0]=V2
    V2I2[:,1,0]=I2
    Vd=np.matmul(ABCDdevice,V2I2)[:,0,0]
    Id=np.matmul(ABCDdevice,V2I2)[:,1,0]
    
    plt.plot(freqs/1e6,np.abs(Vd))
    plt.title(title)
    plt.xlabel('Frequencies [MHz]')
    plt.ylabel('X - abs(transfer function) V$_{in}$ : abs(FFT(V)/FFT(V))')
    plt.show()

    return Vd,Id



V2,V2balun,I2=ComputeTFfromABCD(ABCDtot,ABCDwbalun,Zload)
V2,V2balun,I2=ComputeTFfromABCD(ABCDwbalun,ABCDwbalun,ZADC)

VinVGA,I=ComputeVoltageAtDevice(V2,I2,np.matmul(fromStoABCD(sVGAFilter,50,50),fromStoABCD(sFinalBalun,50,50)))
VinCable,I=ComputeVoltageAtDevice(V2,I2,np.matmul(fromStoABCD(sCableConnector,50,50),np.matmul(fromStoABCD(sVGAFilter,50,50),fromStoABCD(sFinalBalun,50,50))))
VinLNA,I=ComputeVoltageAtDevice(V2,I2,np.matmul(fromStoABCD(sLNA,50,50),np.matmul(fromStoABCD(sCableConnector,50,50),np.matmul(fromStoABCD(sVGAFilter,50,50),fromStoABCD(sFinalBalun,50,50)))))


np.savetxt('VinCable_TF2_20dB_'+name[axis],VinCable)

plt.plot(np.abs(VinCable)/np.abs(VinLNA))
plt.show()


xport= [1.15142632e-02, 9.56762303e-03, 9.01752803e-03, 6.39480958e-03,
        7.45570613e-03, 4.10122657e-03, 3.05211521e-03, 1.78475876e-03,
        2.25756504e-03, 1.58114526e-02, 4.38927971e-02, 1.02365643e-01,
        2.05228806e-01, 3.60086530e-01, 5.93196571e-01, 9.25769210e-01,
        1.28635180e+00, 1.59974515e+00, 1.82166755e+00, 1.97456181e+00,
        2.10040212e+00, 2.32264352e+00, 2.49169230e+00, 2.69539428e+00,
        2.89127493e+00, 3.09583688e+00, 3.32447124e+00, 3.56471157e+00,
        3.82550406e+00, 4.11181355e+00, 4.40257788e+00, 4.70211124e+00,
        5.00654745e+00, 5.32694864e+00, 5.67093563e+00, 6.01775408e+00,
        6.38295126e+00, 6.70471621e+00, 6.85342216e+00, 7.02735710e+00,
        7.14921331e+00, 7.25080729e+00, 7.37718821e+00, 7.53211594e+00,
        7.82728672e+00, 8.05907631e+00, 8.53736687e+00, 9.02558899e+00,
        9.53004932e+00, 1.01325331e+01, 1.06441174e+01, 1.09245968e+01,
        1.10267057e+01, 1.08172646e+01, 1.04337921e+01, 9.98876381e+00,
        9.60518456e+00, 9.32944965e+00, 9.12734222e+00, 8.95675945e+00,
        8.93840694e+00, 9.00773144e+00, 9.22714329e+00, 9.50271416e+00,
        9.67949295e+00, 9.79190254e+00, 9.90741920e+00, 9.71824646e+00,
        9.61033058e+00, 9.22362709e+00, 8.75301743e+00, 8.40423679e+00,
        8.08068848e+00, 7.88950682e+00, 7.56705713e+00, 7.47055292e+00,
        7.50354671e+00, 7.61571121e+00, 7.76245975e+00, 7.85155821e+00,
        8.05863953e+00, 8.03416348e+00, 7.79636812e+00, 7.38478994e+00,
        6.85185623e+00, 6.29469156e+00, 5.75399590e+00, 5.36855316e+00,
        4.99618149e+00, 4.74234533e+00, 4.55757236e+00, 4.41404295e+00,
        4.34133291e+00, 4.38702536e+00, 4.50606298e+00, 4.54809427e+00,
        4.72271156e+00, 4.85595179e+00, 4.98128510e+00, 5.11016178e+00,
        5.20790339e+00, 5.17509747e+00, 5.00971031e+00, 4.81812143e+00,
        4.60166216e+00, 4.35388851e+00, 4.14661551e+00, 3.99804950e+00,
        3.91199327e+00, 3.80525923e+00, 3.77258539e+00, 3.73741674e+00,
        3.72234392e+00, 3.73558331e+00, 3.78327966e+00, 3.83971047e+00,
        3.82089639e+00, 3.77256703e+00, 3.65165472e+00, 3.48889685e+00,
        3.27667451e+00, 3.06055474e+00, 2.86544037e+00, 2.68217421e+00,
        2.56483698e+00, 2.44536209e+00, 2.37354994e+00, 2.34179664e+00,
        2.34855056e+00, 2.40294242e+00, 2.48528481e+00, 2.59292197e+00,
        2.70307136e+00, 2.83066964e+00, 2.94349670e+00, 3.01273084e+00,
        3.00160623e+00, 2.92787409e+00, 2.82812595e+00, 2.73211145e+00,
        2.60898709e+00, 2.47735858e+00, 2.37316275e+00, 2.30630255e+00,
        2.26265121e+00, 2.22448325e+00, 2.21085048e+00, 2.20245194e+00,
        2.20344830e+00, 2.22718358e+00, 2.26376772e+00, 2.32246232e+00,
        2.40657568e+00, 2.44044352e+00, 2.50337529e+00, 2.59040928e+00,
        2.64207745e+00, 2.66859102e+00, 2.68685293e+00, 2.67815018e+00,
        2.63690782e+00, 2.61281228e+00, 2.52057362e+00, 2.41015244e+00,
        2.28733969e+00, 2.14442778e+00, 2.00390196e+00, 1.86110044e+00,
        1.72500658e+00, 1.61054909e+00, 1.51741648e+00, 1.44678915e+00,
        1.38494265e+00, 1.35886133e+00, 1.33750927e+00, 1.35187519e+00,
        1.39803600e+00, 1.46127892e+00, 1.55289316e+00, 1.67136896e+00,
        1.82196009e+00, 1.99497235e+00, 2.16751146e+00, 2.25240397e+00,
        2.24479032e+00, 2.15879869e+00, 2.03224039e+00, 1.90353405e+00,
        1.80063009e+00, 1.75853384e+00, 1.73750281e+00, 1.74828553e+00,
        1.73745203e+00, 1.67877758e+00, 1.53336596e+00, 1.29313266e+00,
        1.03951979e+00, 8.26968372e-01, 6.67322099e-01, 5.51493347e-01,
        4.70588684e-01, 4.05829459e-01, 3.66118848e-01, 3.33587140e-01,
        3.15453231e-01, 3.07469249e-01, 2.90112615e-01, 2.95510471e-01,
        3.21673661e-01, 3.45006257e-01, 3.67464036e-01, 3.83119226e-01,
        3.62607390e-01, 2.74519950e-01, 2.22335488e-01, 1.67803317e-01,
        1.45609587e-01, 1.00103274e-01, 7.32509419e-02, 3.77536491e-02,
        1.84232052e-02, 3.08932308e-02, 2.77359989e-02, 2.25865580e-02,
        5.50979609e-03, 9.29925777e-03, 7.89593458e-02, 1.40129961e-02,
        2.48283520e-03, 2.74268202e-02, 1.80099159e-02, 5.49016558e-02,
        1.89118776e-02, 3.32596824e-02, 5.39521687e-02, 1.28413783e-02,
        2.86616553e-02, 1.24646826e-02, 9.33368318e-03, 1.46251963e-02,
        8.02484434e-03, 1.91197880e-02, 8.76544509e-03, 2.80919415e-03,
        1.38338665e-02, 3.41264135e-03, 3.69141088e-03, 1.61208736e-03,
        1.33743626e-03, 2.26899865e-03, 5.79008483e-04, 4.14328091e-03,
        9.24494059e-04, 8.71596625e-04, 3.15453333e-04, 4.40536533e-04,
        5.05875505e-04, 3.41821578e-04, 8.05259624e-05, 1.23272504e-04,
        9.39382648e-04, 2.30277248e-04, 1.38045580e-04, 8.91278469e-05,
        1.22159749e-04, 1.70646497e-04, 2.27096854e-04, 2.75704457e-04,
        3.05990106e-04, 1.60434822e-04, 1.46231556e-04, 5.55035222e-05,
        6.96420684e-05, 6.90791057e-05, 6.57057681e-05, 6.30408540e-05,
        7.09366577e-05, 6.81002130e-05, 3.77587712e-05, 1.18739896e-04,
        5.08533267e-05, 3.93986411e-05, 5.34228748e-05, 5.99980485e-05,
        1.57910923e-04, 9.10050876e-05, 4.62506141e-05, 4.23386409e-05,
        5.69976473e-05, 1.73956621e-04, 1.15790062e-04]



title='Device = Full V$_2$ RF chain'
plt.plot(freqs/1e6,np.abs(V2),color='orange')
if axis==3:
   plt.plot(freqs/1e6,zport)
else:
   plt.plot(freqs/1e6,xport[:-1],color='black',linestyle='dashed')
plt.title(title)
plt.xlabel('Frequencies [MHz]')
plt.ylabel('X abs(transfer function) : abs(FFT(V$_L$)/FFT(V$_{oc}))$')
plt.legend(['After','Before'])
plt.show()


plt.plot(freqs/1e6,np.abs(V2)*2)
plt.plot(freqs/1e6,np.abs(V2balun))
plt.title(title)
plt.xlabel('Frequencies [MHz]')
plt.ylabel('X abs(transfer function) : abs(FFT(V$_L$)/FFT(V$_{oc}))$')
plt.legend(['Theoretical final balun','S param final balun'])
plt.show()



plt.plot(freqs/1e6,np.angle(V2),color='orange')
plt.title(title)
plt.xlabel('Frequencies [MHz]')
plt.ylabel('X abs(transfer function) : V$_L$/V$_{oc}$')
plt.show()



sCableConnector=np.flip(sCableConnector,(1,2))
plotalgebra(sCableConnector,'sCableConnector')
ABCD=np.matmul(np.matmul(np.matmul(fromStoABCD(sLNA,100,100),fromStoABCD(sLNABalun,50,50)),fromStoABCD(sCableConnector,50,50)),fromStoABCD(sVGAFilter,50,50))
V2p=ComputeTFfromABCD(ABCD,ABCD)


plt.plot(np.abs(V2))
plt.plot(np.abs(V2p))
plt.title(title)
plt.xlabel('Frequencies [MHz]')
plt.ylabel('abs(transfer function) : V$_L$/V$_{oc}$')
plt.legend(['sCableConnector','Flipped sCableConnector'])
plt.show()

#np.save('transferfunction',V2)








    
    
    
    
